## bitcoinAlertWithTelegram

This is Python based Bitcoin alert system .

github link : https://github.com/praveenNagaraj97-au7/Bitcoin-Alert-Based-on-Python

Create IFTTT service using IFTTT app or website 

use webhooks and telegram service


How to run the code

this line will run the code : 

import bitcoin

To link Your IFTTT Key and Event name 

bitcoin.link_telegram()

to get the latest bitcoin price with respect to country 

bitcoin.getPrice()

to get Indian bitcoin updates 

bitcoin.joinChannel()

join the channel here : Telegram link: http://t.me/praveenNagaraj to get notified!